@@ -1,4 +1,4 @@
-"""Top-level package for opTopic."""
+"""Top-level package for OCTIS."""
 from octis.dashboard import *
 from octis.configuration import *
 from octis.dataset import *
@@ -9,4 +9,4 @@ from octis.preprocessing import *
 
 __author__ = """Silvia Terragni"""
 __email__ = 's.terragni4@campus.unimib.it'
-__version__ = '0.4.0'
+__version__ = '1.0.1'
